package com.SpectacleWeb;

import com.SpectacleMng.*;
import java.util.*;

public class SpectacleServlet {

	String id = "";
	String lettre   = "";
	String titre   = "";
	String genre   = "";
	String description   = "";

	// ----------------------------------------
	// modificateur
	public void setId(String id)
	{
		this.id = id;
	}

	public void setLettre(String lettre)
	{
		this.lettre = lettre;
	}

	public void setTitre(String titre)
	{
		this.titre = titre;
	}

	public void setGenre(String genre)
	{
		this.genre = genre;
	}

	public void setDescription(String description)
	{
		this.description = description;
	}



	// ----------------------------------------
	// accesseurs
	public String getId()
	{
		return id;
	}

	public String getLettre()
	{
		return lettre;
	}

	public String getTitre()
	{
		return titre;
	}

	public String getGenre()
	{
		return genre;
	}

	public String getDescription()
	{
		return description;
	}



	// ----------------------------------------
	// traitement



	/* Retourne tous les spectacles
	 *
	 * @return	Collection	ensemble des spectacles  retourner
	 */
	public Collection getAllSpectacles()
	{
		SpectacleHome home = SpectacleClient.getHome();
		return SpectacleClient.getAllSpectacles(home);
	}


	/* Retourne les spectacles dont le titre commence par une certaine 
	 * (ou un certain ensemble de lettres)
	 *
	 * @param	String		lettre de dbut des noms de spectacle  retourner
	 *
	 * @return	Collection	ensemble des spectacles  retourner
	 */
	public Collection getAlphabeticalSpectacles(String uneLettre) throws Exception
	{
		Collection tousSpectacles;
		Vector spectaclesRetournes;
		Spectacle unSpectacle;

		spectaclesRetournes = new Vector();
		SpectacleHome home = SpectacleClient.getHome();
		tousSpectacles = SpectacleClient.getAllSpectacles(home);

		Iterator iterateur = tousSpectacles.iterator();
		while ( iterateur.hasNext() )
		{
			unSpectacle = (Spectacle) iterateur.next();
			if ( unSpectacle.getTitre().toLowerCase().startsWith(uneLettre.toLowerCase()) )
			{
				spectaclesRetournes.add(unSpectacle);
			}
		}
		return spectaclesRetournes;
	}


	/* Retourne la liste des seances pour un spectacle donn
	 *
	 * @param	String		nom du spectacle pour lequel les 
	 *				sances sont recherches
	 *
	 * @return	Collection	liste des seances
	 */
	public Collection getSeances(String nomSpectacle)
	{
		SeanceHome home = SeanceClient.getHome();
		return SeanceClient.getSeancesBySpectacle(home, nomSpectacle);
	}


	/* Retourne la liste des seances dans un thatre donn
	 *
	 * @param	String		nom du thatre pour lequel les 
	 *				sances sont recherches
	 *
	 * @return	Collection	liste des seances
	 */
	public Collection getSeancesFromTheatre(String nomTheatre)
	{
		SeanceHome home = SeanceClient.getHome();
		return SeanceClient.getSeancesByTheatre(home, nomTheatre);
	}


	/* Retourne un spectacle en fonction de son nom
	 *
	 * @return	Spectacle	spectacle  retourner
	 */
	public Spectacle getSpectacle()
	{
		SpectacleHome home = SpectacleClient.getHome();
		return SpectacleClient.getSpectacle(home, id);
	}


	/* Retourne les spectacles qui correspondent  certaines contraintes
	 *
	 * @param	String		chaine devant tre contenue dans le titre
	 * @param	String		chaine devant tre contenue dans la description
	 * @param	String		chaine devant tre contenue dans le genre
	 *
	 * @return	Collection	ensemble des spectacles  retourner
	 */
	public Collection getSpectaclesWhere(String unTitre, String uneDescription, String unGenre) throws Exception
	{
		Collection tousSpectacles;
		Vector spectaclesRetournes;
		Spectacle unSpectacle;
		boolean titreConvenable;
		boolean genreConvenable;
		boolean descriptionConvenable;

		spectaclesRetournes = new Vector();
		SpectacleHome home = SpectacleClient.getHome();
		tousSpectacles = SpectacleClient.getAllSpectacles(home);

System.out.println("parametres : (" + unTitre + ",-" + uneDescription + ",-" + unGenre + ")");
		Iterator iterateur = tousSpectacles.iterator();
		while ( iterateur.hasNext() )
		{
			unSpectacle = (Spectacle) iterateur.next();
			titreConvenable = unSpectacle.getTitre().toLowerCase().matches("(?i).*" + unTitre.toLowerCase() + ".*");
			genreConvenable = unSpectacle.getGenre().toLowerCase().matches("(?i).*" + unGenre.toLowerCase() + ".*");
			descriptionConvenable = unSpectacle.getDescription().toLowerCase().matches("(?i).*" + uneDescription.toLowerCase() + ".*");
                        //System.out.println("Examen de " + unSpectacle.getTitre());
                        if ( titreConvenable )
                        {
                        //System.out.println("------- titre acceptable");
                        }
                        if ( descriptionConvenable )
                        {
                        //System.out.println("------- description acceptable");
                        }
                        if ( genreConvenable )
                        {
                        //System.out.println("------- genre acceptable");
                        }
      			if ( titreConvenable && descriptionConvenable && genreConvenable )
      			{
                                //System.out.println("--------" + unSpectacle.getTitre() + " ACCEPTABLE");
      				spectaclesRetournes.add(unSpectacle);
      			}
      			else
      			{
                                //System.out.println("--------" + unSpectacle.getTitre() + " NON ACCEPTABLE");
      			}
		}
		return spectaclesRetournes;
	}
} // Classe AccountBean
